@@ -10,7 +10,6 @@ class CrispyAuthenticationForm(AuthenticationForm):
         super(CrispyAuthenticationForm, self).__init__(*args, **kwargs)
 
         helper = FormHelper()
-        helper.form_class = 'form-horizontal form_without_actions_decoration'
         helper.form_method = 'post'
         helper.form_action = '.'
 
@@ -18,14 +17,14 @@ class CrispyAuthenticationForm(AuthenticationForm):
             'username',
             'password',
             FormActions(
-                Submit('submit', 'Ingresar')
+                Submit('submit', 'Ingresar', css_class='btn-lg btn-block')
             ),
             HTML(u"""
             {% load url from future %}
 
             <input type="hidden" name="next" value="{{ next }}" />
 
-            <div class="controls with_margin_top">
+            <div class="form-group with_margin_top password_reset_link">
                 <a href="{% url 'auth_password_reset' %}">
                     ¿Olvidaste tu contraseña?
                 </a>
