@@ -1,4 +1,4 @@
-from django.conf.urls import patterns, url, include
+from django.conf.urls import patterns, url
 from registration.backends.default.views import RegistrationView
 from crispy_forms_registration.forms import CrispyAuthenticationForm
 from crispy_forms_registration.forms import CrispyRegistrationForm
@@ -11,9 +11,6 @@ urlpatterns = patterns(
     url(r'^login/$', 'login', {
         'authentication_form': CrispyAuthenticationForm,
         }, name='login'),
-    url(r'^logout/$', 'logout', {
-        'next_page': '/accounts/login/'
-        }, name='logout'),
     url(r'^password/change/$', 'password_change', {
         'password_change_form': CrispyPasswordChangeForm,
         }, name='auth_password_change'),
@@ -32,8 +29,3 @@ urlpatterns += patterns(
         RegistrationView.as_view(form_class=CrispyRegistrationForm),
         name='registration_register'),
 )
-
-urlpatterns += patterns(
-    '',
-    url(r'', include('registration.backends.default.urls')),
-)
